#
# spec file for package waylock
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           waylock
Version:        0.6.2
Release:        2.1
Summary:        Small screenlocker for Wayland compositors
License:        ISC
URL:            https://github.com/ifreund/waylock
Source0:        https://github.com/ifreund/waylock/releases/download/v%{version}/waylock-%{version}.tar.gz
Source1:        waylock.pamd
Source2:        https://isaacfreund.com/public_key.txt#/%{name}.keyring
Source3:        https://github.com/ifreund/waylock/releases/download/v%{version}/waylock-%{version}.tar.gz.sig
Source4:        https://github.com/ifreund/zig-wayland/archive/b9c6fcb8cab3a85c5583ef371055cb589b1e7b18.tar.gz#/zig-wayland.tar.gz
Source5:        https://github.com/ifreund/zig-xkbcommon/archive/e93ceb0436c66a7e4c727fdb59020e889519e489.tar.gz#/zig-xkbcommon.tar.gz
Patch1:         https://github.com/ifreund/waylock/pull/64/commits/c7a3f2678ed2a31932ee1aaea899f253c4800aba.patch#/0001-update-zig-version.patch
BuildRequires:  pkgconfig
BuildRequires:  scdoc >= 1.9.2
BuildRequires:  zig
BuildRequires:  zig-rpm-macros
BuildRequires:  pkgconfig(pam)
BuildRequires:  pkgconfig(wayland-protocols) >= 1.24
BuildRequires:  pkgconfig(wayland-server) >= 1.20.0
BuildRequires:  pkgconfig(wlroots) >= 0.15.0
BuildRequires:  pkgconfig(xkbcommon)
ExclusiveArch:  x86_64 aarch64 riscv64 %{mips64}

%description
Screenlocker for Wayland compositors implementing ext-session-lock-v1.
(The v1 protocol is robust in that a crashing locker does not
cause the session to be unlocked.)

%prep
%setup -n %{name}-%{version}
sed -i 's/0.6.2/0.7.0-dev/g' build.zig
%patch1 -p1

# Update deps
rm -rv ./deps/zig-wayland/*
rm -rv ./deps/zig-xkbcommon/*
tar -xvf %{SOURCE4} --strip-components=1 -C ./deps/zig-wayland/
tar -xvf %{SOURCE5} --strip-components=1 -C ./deps/zig-xkbcommon/

# Replace with configuration that works in openSUSE
cp %{SOURCE1} ./pam.d/waylock

%build
%zig_build -Dpie

%install
%zig_install -Dpie

# Removes rpmlint error: filelist-forbidden-move-to-usr error
mkdir -p %{buildroot}%{_pam_vendordir}
mv %{buildroot}%{_sysconfdir}/pam.d/%{name} %{buildroot}%{_pam_vendordir}/%{name}
rm -rfv %{buildroot}%{_sysconfdir}

%files
%license LICENSE
%doc README.md
%{_bindir}/waylock
%{_mandir}/man1/waylock.1%{?ext_man}
%{_pam_vendordir}/waylock

%changelog
* Sun Oct 22 2023 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- update 0001-update-zig-version.patch
  * update to support zig version 0.11.0
- Add zig-wayland.tar.gz and zig-xkbcommon.tar.gz
* Sat Oct 21 2023 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Add 0001-update-zig-version.patch
  * update to support zig version 0.11.0
* Tue Feb  7 2023 Jan Engelhardt <jengelh@inai.de>
- Ensure neutrality of descriptions. Trim boastful language
* Tue Feb  7 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 0.6.2:
  * ci: update Zig to 0.10.0 to fix build
  * deps: update zig-wayland to fix aarch64 build
  * Lock: ignore password submission before locked event
  * auth: fix getting username on FreeBSD
- Remove 0000-ignore-password-submission-before-locked-event.patch as
  it is already part of 0.6.2
* Fri Feb  3 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Initial spec for waylock 0.6.1
